@@ -19,6 +19,7 @@ import presalytics.lib
 import presalytics.lib.plugins
 import presalytics.lib.plugins.base
 import presalytics.lib.plugins.reveal
+import presalytics.lib.plugins.external
 import presalytics.lib.templates
 import presalytics.lib.templates.base
 import presalytics.story.util
@@ -134,15 +135,39 @@ class Revealer(presalytics.story.components.Renderer):
                 if root:
                     srcs.append(root)
         allowed = ' '.join(set(srcs))
+        hosts = ["https://presalytics.io", "https://*.presalytics.io"]
+        approved = presalytics.lib.plugins.external.ApprovedExternalLinks().attr_dict.flatten()
+        approved.update(presalytics.lib.plugins.external.ApprovedExternalScripts().attr_dict.flatten())
+        approved.update(presalytics.CONFIG.get("BROWSER_API_HOST", {}))
+        for _, val in approved.items():
+            url = urllib.parse.urlparse(val)
+            host = "{0}://{1}".format(url.scheme, url.netloc)
+            if host not in hosts:
+                hosts.append(host)
 
+        allowed_hosts = ' '.join(set(hosts))
+        frame_hosts = ' '.join(set(self.get_embedded_frame_hosts()))
         tags = [
             '<meta charset="utf-8">',
             '<meta http-equiv="X-UA-Compatible" content="IE=edge">',
             '<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">',
-        #    """<meta http-equiv="Content-Security-Policy" content="default-src 'self' https://*.presalytics.io; script-src 'self' https://*.presalytics.io {0};">""".format(allowed)
+            '<title>Presalytics | ' + self.story_outline.title + '</title>',
+            '<meta name="description" content="' + self.story_outline.description + '" />',
+            """<meta http-equiv="Content-Security-Policy" content="default-src 'self' 'unsafe-eval' 'unsafe-inline' blob: data: {0}; script-src 'self' 'unsafe-eval' 'unsafe-inline' {0} {1}; frame-src 'self' blob: data: {2};">""".format(allowed_hosts, allowed, frame_hosts)
         ]
         return tags
 
+    def get_embedded_frame_hosts(self) -> typing.List[str]:
+        frame_hosts = []
+        for p in self.story_outline.pages:
+            for w in p.widgets:
+                if w.kind == 'url':
+                    url = w.data.get('url')
+                    host = urllib.parse.urlparse(url).netloc  # type: ignore
+                    frame_hosts.append('https://{0}'.format(host))
+        return frame_hosts
+
+
     def package_as_standalone(self):
         """
         Render the story outline as a html document with only the 
